@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Roadie
   # @api private
   # Null Object for the URL rewriter role.
@@ -7,6 +9,8 @@ module Roadie
   class NullUrlRewriter
     def initialize(generator = nil) end
     def transform_dom(dom) end
-    def transform_css(css) end
+    def transform_css(css)
+      css
+    end
   end
 end
