@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Roadie
   # Domain object that represents a stylesheet (from disc, perhaps).
   #
@@ -6,7 +8,7 @@ module Roadie
   # @attr_reader [String] name the name of the stylesheet ("stylesheets/main.css", "Admin user styles", etc.). The name of the stylesheet will be visible if any errors occur.
   # @attr_reader [Array<StyleBlock>] blocks
   class Stylesheet
-    BOM = "\xEF\xBB\xBF".force_encoding('UTF-8').freeze
+    BOM = (+"\xEF\xBB\xBF").force_encoding('UTF-8').freeze
 
     attr_reader :name, :blocks
 
@@ -19,18 +21,6 @@ module Roadie
       @blocks = parse_blocks(css.sub(BOM, ""))
     end
 
-    # @yield [selector, properties]
-    # @yieldparam [Selector] selector
-    # @yieldparam [Array<StyleProperty>] properties
-    # @deprecated Iterate over the #{blocks} instead. Will be removed on version 4.0.
-    def each_inlinable_block(&block)
-      # #map and then #each in order to support chained enumerations, etc. if
-      # no block is provided
-      inlinable_blocks.map { |style_block|
-        [style_block.selector, style_block.properties]
-      }.each(&block)
-    end
-
     def to_s
       blocks.join("\n")
     end
@@ -43,17 +33,16 @@ module Roadie
     def parse_blocks(css)
       blocks = []
       parser = setup_parser(css)
-
       parser.each_rule_set do |rule_set, media_types|
         rule_set.selectors.each do |selector_string|
-          blocks << create_style_block(selector_string, rule_set)
+          blocks << create_style_block(selector_string, rule_set, media_types)
         end
       end
 
       blocks
     end
 
-    def create_style_block(selector_string, rule_set)
+    def create_style_block(selector_string, rule_set, media_types)
       specificity = CssParser.calculate_specificity(selector_string)
       selector = Selector.new(selector_string, specificity)
       properties = []
@@ -62,7 +51,7 @@ module Roadie
         properties << StyleProperty.new(prop, val, important, specificity)
       end
 
-      StyleBlock.new(selector, properties)
+      StyleBlock.new(selector, properties, media_types)
     end
 
     def setup_parser(css)
